aboutsummaryrefslogtreecommitdiffstats
path: root/Software/PMR/Messages
diff options
context:
space:
mode:
authorRoy Ben Shabat <Roy.mail.net@gmail.com>2020-11-07 23:50:16 +0200
committerRoy Ben Shabat <Roy.mail.net@gmail.com>2020-11-07 23:50:16 +0200
commit2dbac1046c61d5542056c12f5dabfac92f7d9594 (patch)
treeb78a5dae8a0f4070817b47bce2ecb3a7e15f421a /Software/PMR/Messages
parent5257bfef6cf9fc4896fe417233e7535401c4e5e1 (diff)
downloadTango-2dbac1046c61d5542056c12f5dabfac92f7d9594.tar.gz
Tango-2dbac1046c61d5542056c12f5dabfac92f7d9594.zip
Updated event types to rev 27.
Diffstat (limited to 'Software/PMR/Messages')
-rw-r--r--Software/PMR/Messages/Diagnostics/EventType.proto78
1 files changed, 60 insertions, 18 deletions
diff --git a/Software/PMR/Messages/Diagnostics/EventType.proto b/Software/PMR/Messages/Diagnostics/EventType.proto
index 2c2d76da3..075b39fa6 100644
--- a/Software/PMR/Messages/Diagnostics/EventType.proto
+++ b/Software/PMR/Messages/Diagnostics/EventType.proto
@@ -79,7 +79,7 @@ enum EventType
//Cover is open. Cannot execute job (Group = GeneralHardware, Category = Error)
FRONT_COVER_4_OPEN = 2005;
- //Cartridges door is open. Cannot start new job (Group = GeneralHardware, Category = Warning)
+ //IFS door is open. Cannot start new job (Group = GeneralHardware, Category = Warning)
CARTRIDGES_COVER_OPEN = 2006;
//Cover is open. Cannot execute job (Group = GeneralHardware, Category = Error)
@@ -97,7 +97,7 @@ enum EventType
//Electrical cabinet fans RPM is too low. Cannot execute job (Group = GeneralHardware, Category = Warning)
ELECTRICAL_CABINET_FANS_RPM_TOO_LOW = 2011;
- //Electrical cabinet fans stopped. Cannot execute job (Group = GeneralHardware, Category = Critical)
+ //Electrical cabinet fans stopped. Cannot execute job (Group = GeneralHardware, Category = Warning)
ELECTRICAL_CABINET_FANS_STOPPED = 2012;
//Configuration file does not exist. Cannot execute job (Group = GeneralHardware, Category = Error)
@@ -127,6 +127,15 @@ enum EventType
//Temperature measurement error has occurred. Cannot execute job. (Group = GeneralHardware, Category = Error)
TEMPERATURE_MEASUREMENT_ERROR = 2021;
+ //Cannot read the cartridge. Cannot perform ink filling (Group = GeneralHardware, Category = Error)
+ RFID_READER_MALFUNCTION_INK_SLOT = 2022;
+
+ //Cannot read the cartridge. Cannot replace waste cartridge (Group = GeneralHardware, Category = Error)
+ RFID_READER_MALFUNCTION_WASTE_SLOT_1 = 2023;
+
+ //Cannot read the cartridge. Cannot replace waste cartridge (Group = GeneralHardware, Category = Error)
+ RFID_READER_MALFUNCTION_WASTE_SLOT_2 = 2024;
+
//Thread break. Cannot execute job (Group = ThreadFeedingSystem, Category = Error)
THREAD_BREAK = 3000;
@@ -301,7 +310,7 @@ enum EventType
//The temperature in dryer zone is too high. Cannot execute job (Group = Dryer, Category = Critical)
DRYER_ZONE_1_OVERTEMPERATURE = 4005;
- //The temperature in dryer zone is too high. Cannot execute job (Group = Dryer, Category = Critical)
+ //The temperature in dryer zone is too high. Cannot execute job (Group = Dryer, Category = Error)
DRYER_ZONE_2_OVERTEMPERATURE = 4006;
//The temperature in dryer zone is too low. Cannot execute job (Group = Dryer, Category = Warning)
@@ -316,16 +325,16 @@ enum EventType
//Thermal cut-off. Cannot execute job (Group = Dryer, Category = Critical)
DRYER_THERMAL_CUTOFF = 4010;
- //Dryer zone current is out of range. Cannot execute job (Group = Dryer, Category = Critical)
+ //Dryer zone current is out of range. Cannot execute job (Group = Dryer, Category = Warning)
DRYER_HEATERS_ZONE_1_CURRENT_OUT_OF_RANGE = 4011;
- //Dryer zone current is out of range. Cannot execute job (Group = Dryer, Category = Critical)
+ //Dryer zone current is out of range. Cannot execute job (Group = Dryer, Category = Warning)
DRYER_HEATERS_ZONE_2_CURRENT_OUT_OF_RANGE = 4012;
- //Dryer zone current loop break. Cannot execute job (Group = Dryer, Category = Critical)
+ //Dryer zone current loop break. Cannot execute job (Group = Dryer, Category = Error)
DRYER_HEATERS_ZONE_1_CURRENT_LOOP_BREAK = 4013;
- //Dryer zone current loop break. Cannot execute job (Group = Dryer, Category = Critical)
+ //Dryer zone current loop break. Cannot execute job (Group = Dryer, Category = Error)
DRYER_HEATERS_ZONE_2_CURRENT_LOOP_BREAK = 4014;
//Dryer fan RPM is too low. Cannot execute job (Group = Dryer, Category = Warning)
@@ -478,22 +487,22 @@ enum EventType
//The voltage in dyeing head cleaning head motor is too low. Cannot execute job (Group = DyeingHead, Category = Warning)
DYEING_HEAD_CLEANING_HEAD_MOTOR_UNDERVOLTAGE = 5042;
- //The temperature in dyeing head zone is too high. Cannot execute job (Group = DyeingHead, Category = Critical)
+ //The temperature in dyeing head zone is too high. Cannot execute job (Group = DyeingHead, Category = Error)
DYEING_HEAD_ZONE_7_OVERTEMPERATURE = 5043;
- //The temperature in dyeing head zone is too high. Cannot execute job (Group = DyeingHead, Category = Critical)
+ //The temperature in dyeing head zone is too high. Cannot execute job (Group = DyeingHead, Category = Error)
DYEING_HEAD_ZONE_8_OVERTEMPERATURE = 5044;
- //The temperature in dyeing head zone is too high. Cannot execute job (Group = DyeingHead, Category = Critical)
+ //The temperature in dyeing head zone is too high. Cannot execute job (Group = DyeingHead, Category = Error)
DYEING_HEAD_ZONE_9_OVERTEMPERATURE = 5045;
- //The temperature in dyeing head zone is too high. Cannot execute job (Group = DyeingHead, Category = Critical)
+ //The temperature in dyeing head zone is too high. Cannot execute job (Group = DyeingHead, Category = Error)
DYEING_HEAD_ZONE_10_OVERTEMPERATURE = 5046;
- //The temperature in dyeing head zone is too high. Cannot execute job (Group = DyeingHead, Category = Critical)
+ //The temperature in dyeing head zone is too high. Cannot execute job (Group = DyeingHead, Category = Error)
DYEING_HEAD_ZONE_11_OVERTEMPERATURE = 5047;
- //The temperature in dyeing head zone is too high. Cannot execute job (Group = DyeingHead, Category = Critical)
+ //The temperature in dyeing head zone is too high. Cannot execute job (Group = DyeingHead, Category = Error)
DYEING_HEAD_ZONE_12_OVERTEMPERATURE = 5048;
//The temperature in dyeing head zone is too low. Cannot execute job (Group = DyeingHead, Category = Warning)
@@ -574,10 +583,10 @@ enum EventType
//Dyeing head zone current loop break. Cannot execute job (Group = DyeingHead, Category = Error)
DYEING_HEAD_ZONE_12_CURRENT_LOOP_BREAK = 5074;
- //The temperature in dyeing head blower is too high. Cannot execute job (Group = DyeingHead, Category = Critical)
+ //The temperature in dyeing head blower is too high. Cannot execute job (Group = DyeingHead, Category = Error)
DYEING_HEAD_BLOWER_1_OVERTEMPERATURE = 5075;
- //The temperature in dyeing head blower is too high. Cannot execute job (Group = DyeingHead, Category = Critical)
+ //The temperature in dyeing head blower is too high. Cannot execute job (Group = DyeingHead, Category = Error)
DYEING_HEAD_BLOWER_2_OVERTEMPERATURE = 5076;
//The temperature in dyeing head blower is too low. Cannot execute job (Group = DyeingHead, Category = Warning)
@@ -646,7 +655,7 @@ enum EventType
//Dyeing head tunnel lid is open. Cannot execute job (Group = DyeingHead, Category = Error)
DYEING_HEAD_TUNNEL_LID_IS_OPEN = 5098;
- //The temperature in the mixer is too high. Cannot execute job (Group = Mixer, Category = Critical)
+ //The temperature in the mixer is too high. Cannot execute job (Group = Mixer, Category = Error)
MIXER_OVERTEMPERATURE = 6000;
//The temperature in the mixer is too low. Cannot execute job (Group = Mixer, Category = Warning)
@@ -1099,10 +1108,10 @@ enum EventType
//Cannot identify ink cartridge. Cannot execute job (Group = InkFillingSystem, Category = Error)
INK_CARTRIDGE_RFID_TIMEOUT = 10001;
//Waste level is high. Insert waste cartridge (Group = InkFillingSystem, Category = Warning)
NO_WASTE_CARTRIDGE_AVAILABLE = 10002;
- //Waste cartridge detected. Cannot execute job. Please extract waste cartridge (Group = InkFillingSystem, Category = Error)
+ //Both waste cartridges are full. Cannot execute job. Please replace waste cartridges (Group = InkFillingSystem, Category = Error)
ALL_WASTE_CARTRIDGES_FULL = 10003;
//Cannot detect waste cartridge. Cannot execute job (Group = InkFillingSystem, Category = Error)
@@ -1111,4 +1120,37 @@ enum EventType
//Cannot identify waste cartridge. Cannot execute job (Group = InkFillingSystem, Category = Error)
WASTE_CARTRIDGE_RFID_TIMEOUT = 10005;
+ //Ink cartridge failure. Cannot perform ink filling (Group = InkFillingSystem, Category = Error)
+ INK_CARTRIDGE_RFID_TAG_CANNOT_BE_READ = 10006;
+
+ //Waste cartridge failure. Cannot replace waste cartridge (Group = InkFillingSystem, Category = Error)
+ WASTE_CARTRIDGE_RFID_TAG_CANNOT_BE_READ = 10007;
+
+ //Ink cartridge failure. Cannot perform ink filling (Group = InkFillingSystem, Category = Error)
+ INK_CARTRIDGE_RFID_TAG_IS_NOT_VALID = 10008;
+
+ //Waste cartridge failure. Cannot replace waste cartridge (Group = InkFillingSystem, Category = Error)
+ WASTE_CARTRIDGE_RFID_TAG_IS_NOT_VALID = 10009;
+
+ //Ink cartridge failure. Cannot perform ink filling (Group = InkFillingSystem, Category = Error)
+ INK_CARTRIDGE_AUTHENTICATION_FAILED = 10010;
+
+ //Waste cartridge failure. Cannot replace waste cartridge (Group = InkFillingSystem, Category = Error)
+ WASTE_CARTRIDGE_AUTHENTICATION_FAILED = 10011;
+
+ //Ink cartridge failure. Cannot perform ink filling (Group = InkFillingSystem, Category = Error)
+ INK_CARTRIDGE_IS_BLOCKED = 10012;
+
+ //Waste cartridge failure. Cannot replace waste cartridge (Group = InkFillingSystem, Category = Error)
+ WASTE_CARTRIDGE_IS_BLOCKED = 10013;
+
+ //Ink cartridge failure. Cannot perform ink filling (Group = InkFillingSystem, Category = Error)
+ INK_CARTRIDGE_RFID_TAG_CANNOT_BE_UPDATED = 10014;
+
+ //Waste cartridge failure. Cannot replace waste cartridge (Group = InkFillingSystem, Category = Error)
+ WASTE_CARTRIDGE_RFID_TAG_CANNOT_BE_UPDATED = 10015;
+
+ //Ink in cartridge is expired. Cannot perform ink filling (Group = InkFillingSystem, Category = Warning)
+ INK_IN_CARTRIDGE_IS_EXPIRED = 10016;
+
}
@@ -1099,10 +1108,10 @@ enum EventType
//Cannot identify ink cartridge. Cannot execute job (Group = InkFillingSystem, Category = Error)
INK_CARTRIDGE_RFID_TIMEOUT = 10001;
- //Waste level is high. Insert waste cartridge (Group = InkFillingSystem, Category = Warning)
+ //No waste cartridge in system. Cannot execute job. Please insert waste cartridge (Group = InkFillingSystem, Category = Error)
NO_WASTE_CARTRIDGE_AVAILABLE = 10002;